hedgewars/uTypes.pas
changeset 10040 4ac87acbaed9
parent 10015 4feced261c68
parent 10032 db65298717da
child 10108 c68cf030eded
--- a/hedgewars/uTypes.pas	Tue Jan 21 22:44:37 2014 +0100
+++ b/hedgewars/uTypes.pas	Tue Jan 21 22:53:15 2014 +0100
@@ -272,8 +272,9 @@
             Tag: LongInt;            // Quite generic. Variety of uses.
             FlightTime: Longword;    // Initially added for batting of hogs to determine homerun. Used for some firing delays
             MsgParam: LongWord;      // Initially stored a set of messages. So usually gm values like Message. Frequently overriden
-// These are not used generically, but should probably be used for purpose intended. Definitely should not override pointer type
-            Tex: PTexture;          // A texture created by the gear. Should not use for anything but textures
+// These are not used generically, but should probably be used for purpose intended. Definitely shouldn't override pointer type
+            Tex: PTexture;          // A texture created by the gear. Shouldn't use for anything but textures
+            Tint: LongWord;         // Used to colour a texture
             LinkedGear: PGear;      // Used to track a related gear. Portal pairs for example.
             Hedgehog: PHedgehog;    // set to CurrentHedgehog on gear creation
             SoundChannel: LongInt;  // Used to track a sound the gear started